Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(596)

Unified Diff: lib/html/dart2js/html_dart2js.dart

Issue 11269045: Convert NoMoreElementsException and EmptyQueueException to StateError. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
Download patch
« no previous file with comments | « lib/coreimpl/queue.dart ('k') | lib/html/dartium/html_dartium.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/html/dart2js/html_dart2js.dart
diff --git a/lib/html/dart2js/html_dart2js.dart b/lib/html/dart2js/html_dart2js.dart
index ea5e569f4f71cdc3c681ec12e0ca5a20d885f082..d013f6067584a4149dbd34b1fc16140f6ae9f68f 100644
--- a/lib/html/dart2js/html_dart2js.dart
+++ b/lib/html/dart2js/html_dart2js.dart
@@ -10276,7 +10276,7 @@ class _FilteredElementList implements List {
if (newLength >= len) {
return;
} else if (newLength < 0) {
- throw const ArgumentError("Invalid list length");
+ throw new ArgumentError("Invalid list length");
}
removeRange(newLength - 1, len - newLength);
@@ -11662,11 +11662,11 @@ class _FrozenElementListIterator implements Iterator<Element> {
/**
* Gets the next element in the iteration. Throws a
* [NoMoreElementsException] if no element is left.
*/
Element next() {
if (!hasNext) {
- throw const NoMoreElementsException();
+ throw new StateError("No more elements");
}
return _list[_index++];
@@ -40795,7 +40795,7 @@ class _VariableSizeListIterator<T> implements Iterator<T> {
T next() {
if (!hasNext) {
- throw const NoMoreElementsException();
+ throw new StateError("No more elements");
}
return _array[_pos++];
}
@@ -11662,11 +11662,11 @@ class _FrozenElementListIterator implements Iterator<Element> {
/**
* Gets the next element in the iteration. Throws a
- * [NoMoreElementsException] if no element is left.
+ * [StateError("No more elements")] if no element is left.
*/
Element next() {
« no previous file with comments | « lib/coreimpl/queue.dart ('k') | lib/html/dartium/html_dartium.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698